      subroutine unboundsch(n,energy,nmx,wfn,l,nz,rv,h,v0,v0p,node,     &
        a,b)
!  pgm to solve radial schroedinger equation for unbound states
!    at energy 'energy' and at angular momentum l
!
!    with potential rv/r, given in uniform mesh of n points
!   r=i*h, i=1,...n-1 ;assuming p(r)=C*r**(l+1)*polynomial(r) for r==0;
!                               p((n+1)*h)=0
!  nz=nuclear charge
!
!  uses Noumerov algorithm
!
!  For l=0,1 corrections are needed to approximate wfn(r=0)
!     These depend upon:
!         e0 (current guess of energy eigenvalue)
!         l,nz
!         v(0) == v0 electronic potential at r=0
!         v'(0) == v0p derivative of electronic potential at r=0
!
! also returns node == number of nodes for calculated state
!
      implicit real*8 (a-h,o-z)
      dimension rv(n),wfn(nmx)
      dimension a(nmx),b(nmx)
      ierr=0
      if (n.gt.nmx) then
       write(6,*) 'error in boundsch -- n,nmx = ',n,nmx
       stop
       endif
      angm=l*(l+1)
      eh2=energy*h*h
      do 10 i=1,n
      a(i)=angm/(i*i)+h*rv(i)/i
   10 continue
      do 12 i=1,n
      b(i)=-1.2d0+0.1d0*a(i)
   12 continue
      ssl=0.1d0
      ssd=1.d0
      do 14 i=1,n
   14 a(i)=2.4d0+a(i)
!      write(6,*) 'z , l = ',nz,l
!
!  start outward integration
!    correct behavior near r=0
      b0p0=0
      if (l.gt.1) go to 101
      c1=-nz/(l+1.d0)
      c2=((v0-energy)-2*nz*c1)/(4*l+6.d0)
      c3=(v0p+(v0-energy)*c1-2*nz*c2)/(6*l+12.d0)
      fact=1.d0+h*(c1+h*(c2+h*c3))
      if (l.eq.0) then
        b0p0=-0.2d0*h*nz/fact
        endif
      if (l.eq.1) then
        b0p0=0.2d0/fact
        endif
  101 continue
      node=0
      wfn(1)=h**(l+1)
      wfn(2)=(a(1)+b0p0-eh2*ssd)*wfn(1)/(eh2*ssl-b(2))
       do j=3,n
       wfn(j)=((a(j-1)-eh2*ssd)*wfn(j-1)+                               &
          (b(j-2)-eh2*ssl)*wfn(j-2))/(eh2*ssl-b(j))
       if (wfn(j)*wfn(j-1).le.0.d0) node=node+1
       enddo
!       write(6,*) ' nodes at e=  ', energy, node
!
! normalize to unity within integration range
!
      scale=1.d0/overlap(n,h,wfn,wfn)
      scale=sign(sqrt(scale),wfn(n-2))
      wfn(1:n)=wfn(1:n)*scale   ! call dscal(n,scale,wfn,1)
      return
       end
